camelot.camelot.view.controls.navpane.PaneButton

Package camelot :: Package camelot :: Package view :: Package controls :: Module navpane :: Class PaneButton |
[hide private]
[frames] | no frames]

# Class PaneButton

source code

Custom made navigation pane pushbutton

Instance Methods | [hide private]
__init__(self, text, buttonicon='', textbold=True, textleft=True, width=160, height=32, objectname='PaneButton', parent=None) | source code
textbold(self) | source code
enterEvent(self, event) | source code
leaveEvent(self, event) | source code
mousePressEvent(self, event) | source code

Class Variables | [hide private]
| INDEX = `0`